"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs = require("fs");
var path = require("path");
var plugin_1 = require("@stryker-mutator/api/plugin");
exports.CONFIG_KEY = 'babel';
exports.FILE_KEY = 'optionsFile';
exports.OPTIONS_KEY = 'options';
exports.EXTENSIONS_KEY = 'extensions';
var DEFAULT_BABEL_CONFIG = Object.freeze({
    extensions: Object.freeze([]),
    options: Object.freeze({}),
    optionsFile: '.babelrc'
});
var BabelConfigReader = /** @class */ (function () {
    function BabelConfigReader(log) {
        this.log = log;
    }
    BabelConfigReader.prototype.readConfig = function (strykerOptions) {
        var babelConfig = tslib_1.__assign({}, DEFAULT_BABEL_CONFIG, strykerOptions[exports.CONFIG_KEY]);
        babelConfig.options = tslib_1.__assign({}, this.readBabelOptionsFromFile(babelConfig.optionsFile, babelConfig.optionsApi), babelConfig.options);
        this.log.debug("Babel config is: " + JSON.stringify(babelConfig, null, 2));
        return babelConfig;
    };
    BabelConfigReader.prototype.readBabelOptionsFromFile = function (relativeFileName, optionsApi) {
        if (relativeFileName) {
            var babelrcPath = path.resolve(relativeFileName);
            this.log.debug("Reading .babelrc file from path \"" + babelrcPath + "\"");
            if (fs.existsSync(babelrcPath)) {
                try {
                    if (path.basename(babelrcPath) === '.babelrc.js') {
                        return require(babelrcPath);
                    }
                    if (path.basename(babelrcPath) === 'babel.config.js') {
                        var config = require(babelrcPath);
                        return config(optionsApi);
                    }
                    return JSON.parse(fs.readFileSync(babelrcPath, 'utf8'));
                }
                catch (error) {
                    this.log.error("Error while reading \"" + babelrcPath + "\" file: " + error);
                }
            }
            else {
                this.log.error("babelrc file does not exist at: " + babelrcPath);
            }
        }
        return {};
    };
    BabelConfigReader.inject = plugin_1.tokens(plugin_1.commonTokens.logger);
    return BabelConfigReader;
}());
exports.BabelConfigReader = BabelConfigReader;
//# sourceMappingURL=BabelConfigReader.js.map