"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@stryker-mutator/api/core");
var babel = require("./helpers/babelWrapper");
var path = require("path");
var BabelConfigReader_1 = require("./BabelConfigReader");
var helpers_1 = require("./helpers/helpers");
var util_1 = require("@stryker-mutator/util");
var plugin_1 = require("@stryker-mutator/api/plugin");
var DEFAULT_EXTENSIONS = babel.DEFAULT_EXTENSIONS;
function babelTranspilerFactory(injector) {
    return injector
        .provideClass('babelConfigReader', BabelConfigReader_1.BabelConfigReader)
        .injectClass(BabelTranspiler);
}
exports.babelTranspilerFactory = babelTranspilerFactory;
babelTranspilerFactory.inject = plugin_1.tokens(plugin_1.commonTokens.injector);
var BabelTranspiler = /** @class */ (function () {
    function BabelTranspiler(options, produceSourceMaps, babelConfigReader) {
        if (produceSourceMaps) {
            throw new Error("Invalid `coverageAnalysis` \"" + options.coverageAnalysis + "\" is not supported by the stryker-babel-transpiler. Not able to produce source maps yet. Please set it to \"off\".");
        }
        this.babelConfig = babelConfigReader.readConfig(options);
        this.projectRoot = this.determineProjectRoot();
        this.extensions = DEFAULT_EXTENSIONS.concat(this.babelConfig.extensions);
    }
    BabelTranspiler.prototype.transpile = function (files) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, files.map(function (file) { return _this.transpileFileIfNeeded(file); })];
            });
        });
    };
    BabelTranspiler.prototype.transpileFileIfNeeded = function (file) {
        if (this.extensions.some(function (ext) { return ext === path.extname(file.name); })) {
            try {
                return this.transpileFile(file);
            }
            catch (error) {
                throw new util_1.StrykerError("Error while transpiling \"" + file.name + "\"", error);
            }
        }
        else {
            return file; // pass through
        }
    };
    BabelTranspiler.prototype.transpileFile = function (file) {
        var relativeOptions = {
            cwd: this.projectRoot,
            filename: file.name,
            filenameRelative: path.relative(this.projectRoot, file.name)
        };
        var options = tslib_1.__assign({}, this.babelConfig.options, relativeOptions);
        var result = babel.transformSync(file.textContent, options);
        if (!result) {
            // File is ignored by babel
            return file;
        }
        else if (result.code === undefined || result.code === null) {
            throw new Error("Could not transpile file \"" + file.name + "\". Babel transform function delivered `undefined`.");
        }
        else {
            return new core_1.File(helpers_1.toJSFileName(file.name), result.code);
        }
    };
    BabelTranspiler.prototype.determineProjectRoot = function () {
        var configFile = this.babelConfig.optionsFile;
        if (configFile) {
            return path.dirname(configFile);
        }
        else {
            return process.cwd();
        }
    };
    BabelTranspiler.inject = plugin_1.tokens(plugin_1.commonTokens.options, plugin_1.commonTokens.produceSourceMaps, 'babelConfigReader');
    return BabelTranspiler;
}());
exports.BabelTranspiler = BabelTranspiler;
//# sourceMappingURL=BabelTranspiler.js.map